// game.js for Perlenspiel 3.1
// The following comment lines are for JSLint. Don't remove them!

/*jslint nomen: true, white: true */
/*global PS */

var G = ( function () {
	"use strict";
	var base, obj;

	base = 0; // base of visible page
	obj = {
		drawPage : function () {
			var val, x, y;

			val = base;
			for ( y = 1; y < 17; y += 1 ) {
				for ( x = 0; x < 16; x += 1 ) {
					PS.data( x, y, val ); // save in bead's data
					PS.glyph( x, y, val );
					val += 1;
				}
			}
		},

		showPage : function () {
			PS.statusText( "Page = " + PS.hex( base, 4 ) );
		},

		// Switch to a new page

		newPage : function ( val ) {
			base += val;
			if ( base < 0 ) {
				base = 0;
			}
			else if ( base > 0xFF00 ) {
				base = 0xFF00;
			}
			G.drawPage();
			G.showPage();
			PS.audioPlay( "fx_click" );
		},

		codeString : function ( data ) {
			var x, c;

			x = PS.hex( data, 4 );
			c = String.fromCharCode( data );
			return ( x + " = " + c );
		}
	};

	return obj;
}() );

PS.init = function( system, options ) {
	"use strict";

	PS.gridSize( 16, 17 ); // set initial size
	PS.gridColor( PS.COLOR_BLACK );
	PS.border( PS.ALL, 0, 0 ); // remove borders on top row
	PS.color( PS.ALL, 0, PS.COLOR_BLACK ); // and blacken it

	PS.glyphColor( 7, 0 , PS.COLOR_WHITE );
	PS.glyph( 7, 0, 0x25C0 ); // left arrow
	PS.glyphColor( 8, 0 , PS.COLOR_WHITE );
	PS.glyph( 8, 0, 0x25B6 ); // right arrow

	G.drawPage();

	PS.statusColor( PS.COLOR_WHITE );
	PS.statusText( "Use arrows to page left/right" );

	PS.audioLoad( "fx_click", { lock : true } );
};

PS.touch = function( x, y, data, options ) {
	"use strict";

	if ( y === 0 )	{
		if ( x === 7 ) { // left
			G.newPage(-256);
			PS.glyphColor( x, y, 0x00C000 );
		}
		else if ( x === 8 ) { // right
			G.newPage(256);
			PS.glyphColor( x, y, 0x00C000 );
		}
	}
	else {
		PS.debug( G.codeString( data ) + "\n" );
	}
};

PS.release = function( x, y, data, options ) {
	"use strict";

	if ( ( y === 0 ) && (( x === 7 ) || ( x === 8 )) ) {
		PS.glyphColor( x, y, PS.COLOR_BLACK );
	}
};

PS.enter = function( x, y, data, options ) {
	"use strict";

	if ( y === 0 ) {
		if ( ( x === 7 ) || ( x === 8 ) ) {
			PS.color( x, y, PS.COLOR_WHITE );
			PS.glyphColor( x, y, PS.COLOR_BLACK );
		}
		G.showPage();
	}
	else {
		PS.color( x, y, PS.COLOR_BLACK );
		PS.glyphColor( x, y, PS.COLOR_WHITE );
		PS.statusText( G.codeString( data ) );
	}
};

PS.exit = function( x, y, data, options ) {
	"use strict";

	if ( y > 0 ) {
		PS.color( x, y, PS.COLOR_WHITE );
		PS.glyphColor( x, y, PS.COLOR_BLACK );
	}
	else if ( ( x === 7 ) || ( x === 8 ) ) {
		PS.color( x, y, PS.COLOR_BLACK );
		PS.glyphColor( x, y, PS.COLOR_WHITE );
	}
};

PS.exitGrid = function( options ) {
	"use strict";

	G.showPage();
};

PS.keyDown = function( key, shift, ctrl, options ) {
	"use strict";

	if ( key === PS.KEY_ARROW_LEFT ) {
		G.newPage(-256);
	}
	else if ( key === PS.KEY_ARROW_RIGHT )
	{
		G.newPage(256);
	}
};

PS.keyUp = function( key, shift, ctrl, options ) {
	"use strict";
};

PS.swipe = function( data, options ) {
	"use strict";
};

PS.input = function( sensors, options ) {
	"use strict";
};

